<?xml version="1.0" encoding="utf-8"?>

<xsl:stylesheet version="1.0"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:msxsl="urn:schemas-microsoft-com:xslt"
	xmlns:cs="urn:bugtrack-foresoft-net"
	exclude-result-prefixes="msxsl cs">
	
<msxsl:script language="C#" implements-prefix="cs">
<![CDATA[
public string getValidFileName(string s0)
{
	return String.Join("_", s0.Split(System.IO.Path.GetInvalidFileNameChars()));
}
public string replaceCIDs(string s0, XPathNodeIterator atts)
{
	while(atts.MoveNext())
	{
		XPathNavigator att = atts.Current;
		string cid = att.GetAttribute("cid", "");
		if(cid != "")
		{
			cid = "cid:" + cid;
			string file = getValidFileName(att.GetAttribute("id", "") + "-" + att.GetAttribute("name", ""));
			s0 = s0.Replace(cid, file);
		}
		
	}
	return s0;
}
]]>
</msxsl:script>

<xsl:template match="/">
<html>
<head>
<style>
body, table, input, select, textarea, button {
	font: normal 1em Verdana, Sans-Serif;
}
body {
	font-size: 0.8em;
}
a { color:#336600; }
b { color:#003300; }
.header {font-family: verdana; font-size: 15px; color:#003300; font-weight:bold;}
.back {background-color:#DBF0DB;}
.back2 {background-color:#009933;}			
</style>
</head>

<body>
	<xsl:apply-templates select="bug"/>
</body>
</html>
</xsl:template>
	
<xsl:template match ="bug">
<table border="0" cellpadding="3" cellspacing="1" width="100%">
<tr><td colspan="2" class="header">#<xsl:value-of select="id"/></td></tr>
<tr><td width="100%">
<table border="0" cellpadding="3" cellspacing="1" width="100%">
<xsl:apply-templates select="project"/>
<xsl:apply-templates select="area"/>
<xsl:apply-templates select="title"/>
<xsl:apply-templates select="status"/>
<xsl:apply-templates select="assignedto"/>
<xsl:apply-templates select="priority"/>
<xsl:apply-templates select="version"/>
<xsl:apply-templates select="type"/>
<xsl:apply-templates select="category"/>
<xsl:apply-templates select="phase"/>
<xsl:apply-templates select="cf"/>
<xsl:apply-templates select="description"/>
</table>
</td><td valign="bottom">
<xsl:apply-templates select="duedate"/>
<xsl:apply-templates select="estimate"/>
</td></tr>
</table>
</xsl:template>
	
<xsl:template match="project">
<tr><td nowrap="" valign="top" class="back"><b>Project:</b></td><td width="100%"><xsl:value-of select="text()"/></td></tr>
</xsl:template>

<xsl:template match="area">
<tr><td nowrap="" valign="top" class="back"><b>Area:</b></td><td width="100%"><xsl:value-of select="text()"/></td></tr>
</xsl:template>

<xsl:template match="priority">
<tr><td nowrap="" valign="top" class="back"><b>Priority:</b></td><td width="100%"><xsl:value-of select="text()"/></td></tr>
</xsl:template>

<xsl:template match="version">
<tr><td nowrap="" valign="top" class="back"><b>Fix for:</b></td><td width="100%"><xsl:value-of select="text()"/></td></tr>
</xsl:template>

<xsl:template match="type">
<tr><td nowrap="" valign="top" class="back"><b>Type:</b></td><td width="100%"><xsl:value-of select="text()"/></td></tr>
</xsl:template>

<xsl:template match="category">
<tr><td nowrap="" valign="top" class="back"><b>Category:</b></td><td width="100%"><xsl:value-of select="text()"/></td></tr>
</xsl:template>
	
<xsl:template match="phase">
<tr><td nowrap="" valign="top" class="back"><b>Phase:</b></td><td width="100%"><xsl:value-of select="text()"/></td></tr>
</xsl:template>

<xsl:template match="cf">
<tr><td nowrap="" valign="top" class="back"><b><xsl:value-of select="@name"/>:</b></td><td width="100%"><xsl:value-of select="text()"/></td></tr>
</xsl:template>

<xsl:template match="title">
<tr><td nowrap="" valign="top" class="back"><b>Title:</b></td><td width="100%"><xsl:value-of select="text()"/></td></tr>
</xsl:template>

<xsl:template match="status">
<tr><td nowrap="" valign="top" class="back"><b>Status:</b></td><td width="100%"><xsl:value-of select="text()"/></td></tr>
</xsl:template>

<xsl:template match="assignedto">
<tr><td nowrap="" valign="top" class="back"><b>Assigned to:</b></td><td width="100%"><xsl:value-of select="text()"/></td></tr>
</xsl:template>
	
<xsl:template match="description">
<tr><td valign="top" class="back"><b>Description:</b></td><td>
<table border="0" cellpadding="3" cellspacing="1">
<xsl:for-each select="detail">
<tr><td><xsl:if test="(position() mod 2)=1"><xsl:attribute name="bgcolor">#efefef</xsl:attribute></xsl:if>
<b>
<xsl:value-of select="head"/>
<xsl:if test="position()!=1">
<xsl:if test="changed/priority"><br/>Priority changed to <xsl:value-of select="changed/priority"/></xsl:if>
<xsl:if test="changed/version"><br/>Fix for changed to <xsl:value-of select="changed/version"/></xsl:if>
<xsl:if test="changed/type"><br/>Type changed to <xsl:value-of select="changed/type"/></xsl:if>
<xsl:if test="changed/category"><br/>Category changed to <xsl:value-of select="changed/category"/></xsl:if>
<xsl:if test="changed/phase"><br/>Phase changed to <xsl:value-of select="changed/phase"/></xsl:if>
<xsl:for-each select="changed/cf">
<br/><xsl:value-of select="@name"/> changed to <xsl:value-of select="text()"/>
</xsl:for-each>
<xsl:if test="changed/duedate"><br/>Due date changed to <xsl:value-of select="changed/duedate"/></xsl:if>
<xsl:if test="changed/estimate">
	<xsl:if test="changed/estimate/current"><br/>Current estimate changed to <xsl:value-of select="changed/estimate/current"/></xsl:if>
	<xsl:if test="changed/estimate/elapsed"><br/>Elapsed estimate changed to <xsl:value-of select="changed/estimate/elapsed"/></xsl:if>
</xsl:if>
</xsl:if>
</b><br/>
<xsl:apply-templates select="message"/>
<xsl:for-each select="attachment">
	<xsl:choose>
		<xsl:when test="position()=1">Files: </xsl:when>
		<xsl:otherwise>; </xsl:otherwise>
	</xsl:choose>
	<a target="_blank" href="{cs:getValidFileName(concat(@id,'-',@name))}"><xsl:value-of select="@name"/></a>
</xsl:for-each>
<xsl:choose>
<xsl:when test="body/@format=0"><xsl:apply-templates select="body"/><br/></xsl:when>
<xsl:otherwise>
<table cellpadding="0" cellspacing="0"><tr><td><xsl:value-of disable-output-escaping="yes" select="cs:replaceCIDs(body, attachment)"/></td></tr></table></xsl:otherwise>
</xsl:choose>
</td></tr>
</xsl:for-each>
</table>
</td></tr>
</xsl:template>

<xsl:template match="message">
<table cellpadding="0" cellspacing="0" class="back2" border="0"><tr><td>
<table cellpadding="3" cellspacing="1" border="0">
<tr>
  <td class="back" nowrap=""><b>From:</b></td>
  <td bgcolor="#ffffff" width="100%"><xsl:apply-templates select="recipient[@role=0]"/></td>
</tr>
<tr>
  <td class="back" nowrap=""><b>Date:</b></td>
  <td bgcolor="#ffffff" width="100%"><xsl:value-of select="received"/></td>
</tr>
<xsl:if test="recipient[@role=1]">
 <tr>
  <td class="back" nowrap=""><b>To:</b></td>
  <td bgcolor="#ffffff" width="100%"><xsl:apply-templates select="recipient[@role=1]"/></td>
 </tr>
</xsl:if>
<xsl:if test="recipient[@role=2]">
 <tr>
  <td class="back" nowrap=""><b>Cc:</b></td>
  <td bgcolor="#ffffff" width="100%"><xsl:apply-templates select="recipient[@role=2]"/></td>
 </tr>
</xsl:if>
<tr>
  <td class="back" nowrap=""><b>Subject:</b></td>
  <td bgcolor="#ffffff" width="100%"><xsl:value-of select="subject"/></td>
</tr>
</table>
</td></tr></table>
</xsl:template>

<xsl:template match="recipient">
<a href="mailto:{email}">
 <xsl:choose>
  <xsl:when test="name!=''"><xsl:value-of select="name"/></xsl:when>
  <xsl:otherwise><xsl:value-of select="email"/></xsl:otherwise>
 </xsl:choose>
</a>
<xsl:if test="position()!=last()">
 <xsl:text>; </xsl:text>
</xsl:if>
</xsl:template>

<xsl:template match="attachment">
<xsl:variable name="fn" select="cs:getValidFileName(concat(@id, '-', @name))"/>
<a target="_blank" href="{$fn}"><xsl:value-of select="@name"/></a>
<xsl:if test="position()!=last()"><xsl:text>; </xsl:text></xsl:if>
</xsl:template>

<xsl:template match="br">
<br/>
</xsl:template>
	
<xsl:template match="href">
<a target="_blank" href="{text()}"><xsl:value-of select="text()"/></a>
</xsl:template>

<xsl:template match="estimate">
<xsl:choose>
	<xsl:when test="original/@value=0">
<table cellpadding="1" cellspacing="0" border="0">
<tr><td colspan="2" style="width:150px;height:1px"><div></div></td></tr>
</table>
	</xsl:when>
	<xsl:otherwise>
<table cellpadding="4" cellspacing="0" border="0" style="width:150px;border:1px solid #000000" bgcolor="#f6f6f6">
 <tr><td class="back" colspan="2"><b>Estimates</b></td></tr>
 <tr><td>Original:</td><td width="70%"><i><xsl:value-of select="original"/></i></td></tr>
 <tr><td>Current:</td><td width="70%"><i><xsl:value-of select="current"/></i></td></tr>
 <tr><td>Elapsed:</td><td width="70%"><i><xsl:value-of select="elapsed"/></i></td></tr>
 <tr><td>Remain:</td><td width="70%"><i><xsl:value-of select="remain"/></i></td></tr>
</table>
	</xsl:otherwise>
</xsl:choose>
</xsl:template>

<xsl:template match="duedate">
<p>
<table cellpadding="4" cellspacing="0" style="width:150px;border:solid 1px black" bgcolor="#f6f6f6">
 <tr><td colspan="2" class="back"><b>Due Date</b></td></tr>
 <tr><td nowrap="">Due Date:</td><td width="70%"><i><xsl:value-of select="text()"/></i></td></tr>
</table>
</p>
</xsl:template>

</xsl:stylesheet> 
